==> vradi-swing-0.5.0-sources.jar: com/jurismarches/vradi/ui/admin/helpers/AdminNavigationTreeHelper.java <==
/*
 * #%L
 * Vradi :: Swing
 * 
 * $Id: AdminNavigationTreeHelper.java 1823 2010-12-14 17:31:26Z sletellier $
 * $HeadURL: svn+ssh://sletellier@labs.libre-entreprise.org/svnroot/vradi/vradi/tags/vradi-0.5.0/vradi-swing/src/main/java/com/jurismarches/vradi/ui/admin/helpers/AdminNavigationTreeHelper.java $
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.ui.admin.helpers;

import com.jurismarches.vradi.ui.tree.helpers.VradiTreeHelper;
import javax.swing.tree.TreeModel;

import com.jurismarches.vradi.entities.Client;
import com.jurismarches.vradi.entities.User;
import com.jurismarches.vradi.ui.admin.loadors.ClientUsersNodeLoadors;
import com.jurismarches.vradi.ui.admin.loadors.ClientsAndUsersNodeLoadors;
import com.jurismarches.vradi.ui.admin.loadors.FormTypeNodeLoadors;
import com.jurismarches.vradi.ui.admin.loadors.GroupsNodeLoadors;
import com.jurismarches.vradi.ui.admin.loadors.StreamNodeLoadors;
import jaxx.runtime.swing.nav.tree.NavTreeNodeChildLoador;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import com.jurismarches.vradi.services.VradiService;
import com.jurismarches.vradi.ui.tree.VradiDataProvider;
import com.jurismarches.vradi.ui.tree.VradiTreeNode;
import org.nuiton.wikitty.entities.BusinessEntity;

/**
 * Navigation tree helpers.
 *
 * @author sletellier
 * @see jaxx.runtime.swing.nav.tree.NavTreeHelper
 */
public abstract class AdminNavigationTreeHelper<C extends BusinessEntity> extends VradiTreeHelper<C> {

    /**
     * Logger
     */
    static private final Log log = LogFactory.getLog(AdminNavigationTreeHelper.class);

    public AdminNavigationTreeHelper(VradiDataProvider dataProvider) {
        super();
        setDataProvider(dataProvider);
    }

    public TreeModel createTreeModel() {

        // Create root static node
        VradiTreeNode root = new VradiTreeNode(
                String.class,
                "Root node",
                null,
                null
        );

        VradiTreeNode child = createNode();

        // Add to root
        root.add(child);

        // Create model
        TreeModel model = createModel(root);

        // Populate childs nodes
        root.populateChilds(getBridge(), getDataProvider());

        registerLoadedIds(child);

        return model;
    }

    public abstract VradiTreeNode createNode();
    
    public VradiTreeNode getParentSelectedCategoryNode(String categoryName) {
        return getParentCategoryNode(getSelectedNode(), categoryName);
    }
    
    public static VradiTreeNode getParentCategoryNode(VradiTreeNode node, String categoryName) {
        if (node == null) {
            return null;
        }

        if (node.getId().contains(categoryName)) {
            return node;
        }
        return getParentCategoryNode(node.getParent(), categoryName);
    }

    public VradiTreeNode getParentSelectedNode(Class type) {
        return getParentNode(getSelectedNode(), type);
    }

    public static VradiTreeNode getParentNode(VradiTreeNode node, Class type) {
        if (node == null) {
            return null;
        }

        if (type.equals(node.getInternalClass())) {
            return node;
        }
        return getParentNode(node.getParent(), type);
    }

    public void createNode(Class<? extends NavTreeNodeChildLoador<String, ?, VradiTreeNode>> nodeLoadorsClass, String categoryName) {
        createNode(nodeLoadorsClass, categoryName, null, false);
    }

    public void createNode(Class<? extends NavTreeNodeChildLoador<String, ?, VradiTreeNode>> nodeLoadorsClass,
                           String categoryName, String id, boolean select) {

        VradiTreeNode node = findNode(getRootNode(), id);

        // If not found create it
        if (node == null) {
            VradiTreeNode parentNode = findNode(getRootNode(), categoryName);
            if (parentNode == null) {
                return;
            }
            node = getChildLoador(nodeLoadorsClass).createNode(id, getDataProvider());

            insertNode(parentNode, node);
        }

        // Select
        if (select && getSelectedNode() != null && !getSelectedNode().getId().equals(node.getId())) {
            selectNode(node);
        }
    }

    public void createAndSelectClientNode(String clientId) {
        createClientNode(clientId, true);
    }

    public void createClientNode(String clientId, boolean select) {
        createNode(ClientsAndUsersNodeLoadors.class, AdminBeanConstant.CLIENT.getCategoryName(), clientId, select);
    }

    public void createAndSelectGroupNode(String groupId) {
        createGroupNode(groupId, true);
    }

    public void createGroupNode(String groupId, boolean select) {
        createNode(GroupsNodeLoadors.class, AdminBeanConstant.GROUP.getCategoryName(), groupId, select);
    }

    public void createAndSelectUserNode(String userId, String clientId) {
        createUserNode(userId, clientId, true);
    }

    public void createUserNode(String userId, boolean select) {
        createUserNode(userId, null, select);
    }

    public void createUserNode(String userId, String clientId, boolean select) {
        if (clientId == null) {
            User user = VradiService.getWikittyProxy().restore(User.class, userId);
            if (user == null) {
                return;
            }
            clientId = user.getClient();
        }
        createNode(ClientUsersNodeLoadors.class, clientId + AdminBeanConstant.USER.getCategoryName(), userId, select);
    }

    public void createAndSelectFormTypeNode(String extensionId) {
        createFormTypeNode(extensionId, true);
    }

    public void createFormTypeNode(String extensionId, boolean select) {
        createNode(FormTypeNodeLoadors.class, AdminBeanConstant.FORM_TYPE.getCategoryName(), extensionId, select);
    }

    public void createAndSelectStreamNode(String streamId) {
        createStreamNode(streamId, true);
    }
    
    public void createStreamNode(String streamId, boolean select) {
        createNode(StreamNodeLoadors.class, AdminBeanConstant.XML_STREAM.getCategoryName(), streamId, select);
    }

    /**
     * Method to reselect a category node (during some tree updates, while
     * saving, node id change so, it not possible to reselect using oldPath.
     *
     * @param node The node to reselect
     */
    public void reSelectCategory(VradiTreeNode node){
        String id = node.getParent().getId();
        log.debug ("Try to load subcategory for node : " + id);
        selectNode(id ,node.getId());
    }

    public Client getClientSelected() {
        VradiTreeNode clientNode = getParentSelectedNode(Client.class);
        if (clientNode == null) {
            return null;
        }
        return VradiService.getWikittyProxy().restore(Client.class, clientNode.getId());
    }


}

==> vradi-swing-0.5.1-sources.jar: com/jurismarches/vradi/ui/admin/helpers/AdminNavigationTreeHelper.java <==
/*
 * #%L
 * Vradi :: Swing
 * 
 * $Id: AdminNavigationTreeHelper.java 1864 2010-12-24 12:15:34Z sletellier $
 * $HeadURL: svn+ssh://sletellier@labs.libre-entreprise.org/svnroot/vradi/vradi/tags/vradi-0.5.1/vradi-swing/src/main/java/com/jurismarches/vradi/ui/admin/helpers/AdminNavigationTreeHelper.java $
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.ui.admin.helpers;

import com.jurismarches.vradi.ui.tree.helpers.VradiTreeHelper;
import javax.swing.tree.TreeModel;

import com.jurismarches.vradi.entities.Client;
import com.jurismarches.vradi.entities.User;
import com.jurismarches.vradi.ui.admin.loadors.ClientUsersNodeLoadors;
import com.jurismarches.vradi.ui.admin.loadors.ClientsAndUsersNodeLoadors;
import com.jurismarches.vradi.ui.admin.loadors.FormTypeNodeLoadors;
import com.jurismarches.vradi.ui.admin.loadors.GroupsNodeLoadors;
import com.jurismarches.vradi.ui.admin.loadors.StreamNodeLoadors;
import jaxx.runtime.swing.nav.tree.NavTreeNodeChildLoador;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import com.jurismarches.vradi.services.VradiService;
import com.jurismarches.vradi.ui.tree.VradiDataProvider;
import com.jurismarches.vradi.ui.tree.VradiTreeNode;
import org.nuiton.wikitty.entities.BusinessEntity;

/**
 * Navigation tree helpers.
 *
 * @author sletellier
 * @see jaxx.runtime.swing.nav.tree.NavTreeHelper
 */
public abstract class AdminNavigationTreeHelper<C extends BusinessEntity> extends VradiTreeHelper<C> {

    /**
     * Logger
     */
    static private final Log log = LogFactory.getLog(AdminNavigationTreeHelper.class);

    public AdminNavigationTreeHelper(VradiDataProvider dataProvider) {
        super();
        setDataProvider(dataProvider);
    }

    public TreeModel createTreeModel() {

        // Create root static node
        VradiTreeNode root = new VradiTreeNode(
                String.class,
                "Root node",
                null,
                null
        );

        VradiTreeNode child = createNode();

        // Add to root
        root.add(child);

        // Create model
        TreeModel model = createModel(root);

        // Populate childs nodes
        root.populateChilds(getBridge(), getDataProvider());

        registerLoadedIds(child);

        return model;
    }

    public abstract VradiTreeNode createNode();
    
    public VradiTreeNode getParentSelectedCategoryNode(String categoryName) {
        return getParentCategoryNode(getSelectedNode(), categoryName);
    }
    
    public static VradiTreeNode getParentCategoryNode(VradiTreeNode node, String categoryName) {
        if (node == null) {
            return null;
        }

        if (node.getId().contains(categoryName)) {
            return node;
        }
        return getParentCategoryNode(node.getParent(), categoryName);
    }

    public VradiTreeNode getParentSelectedNode(Class type) {
        return getParentNode(getSelectedNode(), type);
    }

    public static VradiTreeNode getParentNode(VradiTreeNode node, Class type) {
        if (node == null) {
            return null;
        }

        if (type.equals(node.getInternalClass())) {
            return node;
        }
        return getParentNode(node.getParent(), type);
    }

    public void createNode(Class<? extends NavTreeNodeChildLoador<String, ?, VradiTreeNode>> nodeLoadorsClass, String categoryName) {
        createNode(nodeLoadorsClass, categoryName, null, false);
    }

    public void createNode(Class<? extends NavTreeNodeChildLoador<String, ?, VradiTreeNode>> nodeLoadorsClass,
                           String categoryName, String id, boolean select) {

        VradiTreeNode node = findNode(getRootNode(), id);

        // If not found create it
        if (node == null) {
            VradiTreeNode parentNode = findNode(getRootNode(), categoryName);
            if (parentNode == null) {
                return;
            }
            node = getChildLoador(nodeLoadorsClass).createNode(id, getDataProvider());

            insertNode(parentNode, node);
        }

        // Select
        if (select && (getSelectedNode() == null || !getSelectedNode().getId().equals(node.getId()))) {
            selectNode(node);
        }
    }

    public void createAndSelectClientNode(String clientId) {
        createClientNode(clientId, true);
    }

    public void createClientNode(String clientId, boolean select) {
        createNode(ClientsAndUsersNodeLoadors.class, AdminBeanConstant.CLIENT.getCategoryName(), clientId, select);
    }

    public void createAndSelectGroupNode(String groupId) {
        createGroupNode(groupId, true);
    }

    public void createGroupNode(String groupId, boolean select) {
        createNode(GroupsNodeLoadors.class, AdminBeanConstant.GROUP.getCategoryName(), groupId, select);
    }

    public void createAndSelectUserNode(String userId, String clientId) {
        createUserNode(userId, clientId, true);
    }

    public void createUserNode(String userId, boolean select) {
        createUserNode(userId, null, select);
    }

    public void createUserNode(String userId, String clientId, boolean select) {
        if (clientId == null) {
            User user = VradiService.getWikittyProxy().restore(User.class, userId);
            if (user == null) {
                return;
            }
            clientId = user.getClient();
        }
        createNode(ClientUsersNodeLoadors.class, clientId + AdminBeanConstant.USER.getCategoryName(), userId, select);
    }

    public void createAndSelectFormTypeNode(String extensionId) {
        createFormTypeNode(extensionId, true);
    }

    public void createFormTypeNode(String extensionId, boolean select) {
        createNode(FormTypeNodeLoadors.class, AdminBeanConstant.FORM_TYPE.getCategoryName(), extensionId, select);
    }

    public void createAndSelectStreamNode(String streamId) {
        createStreamNode(streamId, true);
    }
    
    public void createStreamNode(String streamId, boolean select) {
        createNode(StreamNodeLoadors.class, AdminBeanConstant.XML_STREAM.getCategoryName(), streamId, select);
    }

    /**
     * Method to reselect a category node (during some tree updates, while
     * saving, node id change so, it not possible to reselect using oldPath.
     *
     * @param node The node to reselect
     */
    public void reSelectCategory(VradiTreeNode node){
        String id = node.getParent().getId();
        log.debug ("Try to load subcategory for node : " + id);
        selectNode(id ,node.getId());
    }

    public Client getClientSelected() {
        VradiTreeNode clientNode = getParentSelectedNode(Client.class);
        if (clientNode == null) {
            return null;
        }
        return VradiService.getWikittyProxy().restore(Client.class, clientNode.getId());
    }


}
